/**
 * Plugin to detect possibly hard to read sentences.
 *
 * @type {import('unified').Plugin<[Options?], Root>}
 */
export default function retextReadability(
  options?: Options | undefined
):
  | void
  | import('unified').Transformer<import('nlcst').Root, import('nlcst').Root>
export type Root = import('nlcst').Root
export type Options = {
  /**
   * Target age group.
   * Note that the different algorithms provide varying results, so your milage
   * may vary with people actually that age.
   */
  age?: number | undefined
  /**
   * Number of algorithms that need to agree.
   * By default, 4 out of the 7 algorithms need to agree that a sentence is hard
   * to read for the target age, in which case it’s warned about.
   */
  threshold?: number | undefined
  /**
   * Minimum number of words a sentence should have when warning.
   * Most algorithms are designed to take a large sample of sentences to detect
   * the body’s reading level.
   * This plugin works on a per-sentence basis and that makes the results quite
   * skewered when a short sentence has a few long words or some unknown ones.
   */
  minWords?: number | undefined
}
